# Changelog

## [0.1.0-a3](https://github.com/gurobokum/liman/compare/liman_py-v0.1.0-a2...liman_py-v0.1.0-a3) (2025-08-15)


### ✨ Features

* **liman:** implement __str__ for ExecutorOutput ([eaccf58](https://github.com/gurobokum/liman/commit/eaccf584cf300967fa7cd86c50a4b11dc279014c))
* **liman:** implement Agent class ([2233933](https://github.com/gurobokum/liman/commit/2233933b2bc5b0c4979d8a64a5964d3a4e70c462))
* **liman:** implement loader ([8d607d0](https://github.com/gurobokum/liman/commit/8d607d04d02f858ba1a68faba79062a230daeac0))


### 📚 Documentation

* **liman:** update README.md ([dc622c7](https://github.com/gurobokum/liman/commit/dc622c7206d1505333f2db5f457206a66dca7b51))
* **liman:** update README.md ([e4e3c33](https://github.com/gurobokum/liman/commit/e4e3c33007b9e7387f024fdd76d0e6f084fc3bb4))

## 0.1.0-a2 (2025-08-13)


### ✨ Features

* add protobuf ([f861ba3](https://github.com/gurobokum/liman/commit/f861ba3133d70ddc2ce083427c5b955a4f736d8f))
* **liman:** implement executor ([39d2b4e](https://github.com/gurobokum/liman/commit/39d2b4ec7b393e73e0b9dc1bc1bd981125df6928))


### 🛠 Code Refactoring

* drop protobuf ([baf82d3](https://github.com/gurobokum/liman/commit/baf82d36c7fe936895eef3e2ab2aa3be541796bd))
* **liman:** rework versioning ([b65a0ad](https://github.com/gurobokum/liman/commit/b65a0ad055fcf651e3bef501aaae3c4b8553ad54))
